==> fcl_0.3.2.orig.tar.gz: fcl-0.3.2/include/fcl/articulated_model/model_config.h <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2011, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/** \author Dalibor Matura, Jia Pan */

#ifndef FCL_ARTICULATED_MODEL_MODEL_CONFIG_H
#define FCL_ARTICULATED_MODEL_MODEL_CONFIG_H

#include "fcl/data_types.h"
#include "fcl/articulated_model/joint_config.h"
#include <string>
#include <map>
#include <boost/weak_ptr.hpp>
#include <boost/shared_ptr.hpp>

namespace fcl
{

class ModelConfig
{
public:
  ModelConfig();

  ModelConfig(const ModelConfig& model_cfg);

  ModelConfig(std::map<std::string, boost::shared_ptr<Joint> > joints_map);

  JointConfig getJointConfigByJointName(const std::string& joint_name) const;
  JointConfig& getJointConfigByJointName(const std::string& joint_name);

  JointConfig getJointConfigByJoint(boost::shared_ptr<Joint> joint) const;
  JointConfig& getJointConfigByJoint(boost::shared_ptr<Joint> joint);

  std::map<std::string, JointConfig> getJointCfgsMap() const
  { return joint_cfgs_map_; }

private:
  std::map<std::string, JointConfig> joint_cfgs_map_;
};


}

#endif

==> fcl_0.5.0.orig.tar.gz: fcl-0.5.0/include/fcl/articulated_model/model_config.h <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2011-2014, Willow Garage, Inc.
 *  Copyright (c) 2014-2016, Open Source Robotics Foundation
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Open Source Robotics Foundation nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/** \author Dalibor Matura, Jia Pan */

#ifndef FCL_ARTICULATED_MODEL_MODEL_CONFIG_H
#define FCL_ARTICULATED_MODEL_MODEL_CONFIG_H

#include "fcl/data_types.h"
#include "fcl/articulated_model/joint_config.h"
#include <string>
#include <map>
#include <memory>

namespace fcl
{

class ModelConfig
{
public:
  ModelConfig();

  ModelConfig(const ModelConfig& model_cfg);

  ModelConfig(std::map<std::string, std::shared_ptr<Joint> > joints_map);

  JointConfig getJointConfigByJointName(const std::string& joint_name) const;
  JointConfig& getJointConfigByJointName(const std::string& joint_name);

  JointConfig getJointConfigByJoint(std::shared_ptr<Joint> joint) const;
  JointConfig& getJointConfigByJoint(std::shared_ptr<Joint> joint);

  std::map<std::string, JointConfig> getJointCfgsMap() const
  { return joint_cfgs_map_; }

private:
  std::map<std::string, JointConfig> joint_cfgs_map_;
};


}

#endif
